<template>
    <header class="pc-header">
        <div class="header-wrapper">
            <!-- Mobile Menu -->
            <div class="me-auto pc-mob-drp">
                <ul class="list-unstyled">
                    <li class="pc-h-item header-mobile-collapse">
                        <a href="#" class="pc-head-link head-link-secondary ms-0" id="sidebar-hide">
                            <i class="ti ti-menu-2"></i>
                        </a>
                    </li>
                    <li class="pc-h-item pc-sidebar-popup">
                        <a href="#" class="pc-head-link head-link-secondary ms-0" id="mobile-collapse">
                            <i class="ti ti-menu-2"></i>
                        </a>
                    </li>
                </ul>
            </div>
            <!-- Right Menu -->
            <div class="ms-auto">
                <ul class="list-unstyled mb-0">
                    <!-- Notification -->
                    <li class="dropdown pc-h-item">
                        <div class="d-flex align-items-center gap-2">
                            <span>{{ userProps.name }}</span>
                            <img :src="`/storage/uploads/${userProps.photo}`" alt="User Photo" class="rounded-circle" width="40" height="40">
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </header>
</template>

<script setup>
import { usePage } from "@inertiajs/vue3";
import { computed, onMounted, watch, onUnmounted } from "vue";

const page = usePage();
const userProps = computed(() => page.props.auth.user);

let sidebarClickHandler = null;
let mobileClickHandler = null;
let overlayClickHandler = null;
let dropdownClickHandlers = [];
let documentClickHandler = null;

const setupSidebarListeners = () => {
    const sidebarToggle = document.getElementById('sidebar-hide');
    const mobileCollapse = document.getElementById('mobile-collapse');
    const sidebar = document.querySelector('.pc-sidebar');
    const overlay = document.createElement('div');
    overlay.classList.add('pc-menu-overlay');

    // Hapus listener sebelumnya agar tidak ganda
    cleanupListeners();

    if (sidebarToggle && sidebar) {
        sidebarClickHandler = () => {
            sidebar.classList.toggle('pc-sidebar-hide');
        };
        sidebarToggle.addEventListener('click', sidebarClickHandler);
    }

    if (mobileCollapse && sidebar) {
        mobileClickHandler = () => {
            if (sidebar.classList.contains('mob-sidebar-active')) {
                sidebar.classList.remove('mob-sidebar-active');
                overlay.remove();
            } else {
                sidebar.classList.add('mob-sidebar-active');
                sidebar.appendChild(overlay);
            }
        };
        mobileCollapse.addEventListener('click', mobileClickHandler);

        overlayClickHandler = () => {
            sidebar.classList.remove('mob-sidebar-active');
            overlay.remove();
        };
        overlay.addEventListener('click', overlayClickHandler);
    }

    // Dropdown handling
    const dropdowns = document.querySelectorAll('.dropdown');
    dropdownClickHandlers = [];

    dropdowns.forEach((dropdown) => {
        const toggle = dropdown.querySelector('.dropdown-toggle');
        const menu = dropdown.querySelector('.dropdown-menu');
        if (toggle && menu) {
            const handler = (e) => {
                e.preventDefault();
                menu.classList.toggle('show');
            };
            toggle.addEventListener('click', handler);
            dropdownClickHandlers.push({ toggle, handler });
        }
    });

    documentClickHandler = (e) => {
        if (!e.target.closest('.dropdown')) {
            dropdowns.forEach((dropdown) => {
                const menu = dropdown.querySelector('.dropdown-menu');
                if (menu) menu.classList.remove('show');
            });
        }
    };
    document.addEventListener('click', documentClickHandler);
};

const cleanupListeners = () => {
    const sidebarToggle = document.getElementById('sidebar-hide');
    const mobileCollapse = document.getElementById('mobile-collapse');

    if (sidebarToggle && sidebarClickHandler) {
        sidebarToggle.removeEventListener('click', sidebarClickHandler);
    }

    if (mobileCollapse && mobileClickHandler) {
        mobileCollapse.removeEventListener('click', mobileClickHandler);
    }

    if (overlayClickHandler) {
        document.querySelector('.pc-menu-overlay')?.removeEventListener('click', overlayClickHandler);
    }

    dropdownClickHandlers.forEach(({ toggle, handler }) => {
        toggle.removeEventListener('click', handler);
    });
    dropdownClickHandlers = [];

    if (documentClickHandler) {
        document.removeEventListener('click', documentClickHandler);
    }
};

onMounted(() => {
    setupSidebarListeners();
});

// Re-run after every Inertia page change
watch(() => page.url, () => {
    setupSidebarListeners();
});

onUnmounted(() => {
    cleanupListeners();
});
</script>
